@@ -1,11 +1,17 @@
 .onLoad<- function(lib, pkg, ...)
 {
-    require(utils)
-    cat("\n",paste("ChainLadder version", packageDescription("ChainLadder")$Version,
+    packageStartupMessage(chainladderWelcomeMessage())
+
+    invisible()
+}
+
+chainladderWelcomeMessage <- function(){
+
+  paste("\nChainLadder version", packageDescription("ChainLadder")$Version,
                    "by:\nMarkus Gesmann <markus.gesmann@gmail.com>",
-                   "\nWayne (Yanwei) Zhang <actuaryzhang@uchicago.edu>",
+                   "\nWayne Zhang <actuary_zhang@hotmail.com>",
                    "\nDaniel Murphy <danielmarkmurphy@gmail.com>",
-                   "\n\n"),
+                   "\n\n",
         "Type library(help='ChainLadder') or ?ChainLadder\n",
         "to see overall documentation.\n\n",
         "Type demo(ChainLadder) to get an idea of the functionality of this package.\n\n",
@@ -16,6 +22,7 @@
         "would\nlike to collaborate.\n\n",
         "More information is available on the ChainLadder project web-site:\n",
         "http://code.google.com/p/chainladder/\n\n",
+        "To suppress this message use the statement:\n",
+        "suppressPackageStartupMessages(library(ChainLadder))\n",       
         sep='')
-  invisible()
-}
+ }
